==> ah-formbuilder-1.2.4.tgz: package/es/utils/selects/SearchableSelect.js <==
var _jsxFileName = "/home/ayesha/Project/formbuilder/src/utils/selects/SearchableSelect.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import TextField from '@material-ui/core/TextField';
import Autocomplete from '@material-ui/lab/Autocomplete';
import FormLabel from "@material-ui/core/FormLabel";
import { makeStyles } from "@material-ui/core/styles";
var useStyles = makeStyles(function (theme) {
  return {
    labelRoot: {
      transform: 'none'
    }
  };
});
export default function SearchableSelect(props) {
  var _this = this;

  var classes = useStyles();
  var options = props.options,
      value = props.value,
      handleChange = props.handleChange,
      label = props.label,
      error = props.error,
      required = props.required,
      placeholder = props.placeholder,
      helperText = props.helperText,
      disabled = props.disabled,
      disableClearable = props.disableClearable;
  var labelProp = props.labelProp ? props.labelProp : 'label';
  var valueProp = props.valueProp ? props.valueProp : 'value';
  var formattedValue = null;

  for (var i = 0; i < options.length; i++) {
    if (options[i][valueProp] === value) {
      formattedValue = options[i];
    }
  }

  return /*#__PURE__*/React.createElement(Autocomplete, {
    disablePortal: true,
    value: formattedValue,
    options: options,
    disabled: disabled,
    getOptionLabel: function getOptionLabel(option) {
      return option[labelProp];
    },
    onChange: function onChange(e, value) {
      handleChange({
        target: {
          value: value[valueProp]
        }
      });
    },
    disableClearable: disableClearable,
    renderInput: function renderInput(params) {
      return /*#__PURE__*/React.createElement(TextField, _extends({}, params, {
        required: required,
        placeholder: value ? "" : placeholder,
        InputLabelProps: {
          shrink: true,
          classes: {
            shrink: classes.labelRoot
          }
        },
        label: label,
        error: !!error,
        helperText: error ? error : helperText ? helperText : null,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 35,
          columnNumber: 30
        }
      }));
    },
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 27,
      columnNumber: 5
    }
  });
}

==> ah-formbuilder-1.2.6.tgz: package/es/utils/selects/SearchableSelect.js <==
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
import React from 'react';
import TextField from '@material-ui/core/TextField';
import Autocomplete from '@material-ui/lab/Autocomplete';
import FormLabel from "@material-ui/core/FormLabel";
import { makeStyles } from "@material-ui/core/styles";
var useStyles = makeStyles(function (theme) {
  return {
    labelRoot: {
      transform: 'none'
    }
  };
});
export default function SearchableSelect(props) {
  var classes = useStyles();
  var options = props.options,
    value = props.value,
    handleChange = props.handleChange,
    label = props.label,
    error = props.error,
    required = props.required,
    placeholder = props.placeholder,
    helperText = props.helperText,
    disabled = props.disabled,
    disableClearable = props.disableClearable;
  var labelProp = props.labelProp ? props.labelProp : 'label';
  var valueProp = props.valueProp ? props.valueProp : 'value';
  var formattedValue = null;
  for (var i = 0; i < options.length; i++) {
    if (options[i][valueProp] === value) {
      formattedValue = options[i];
    }
  }
  return /*#__PURE__*/React.createElement(Autocomplete, {
    disablePortal: true,
    value: formattedValue,
    options: options,
    disabled: disabled,
    getOptionLabel: function getOptionLabel(option) {
      return option[labelProp];
    },
    onChange: function onChange(e, value) {
      handleChange({
        target: {
          value: value[valueProp]
        }
      });
    },
    disableClearable: disableClearable,
    renderInput: function renderInput(params) {
      return /*#__PURE__*/React.createElement(TextField, _extends({}, params, {
        required: required,
        placeholder: value ? "" : placeholder,
        InputLabelProps: {
          shrink: true,
          classes: {
            shrink: classes.labelRoot
          }
        },
        label: label,
        error: !!error,
        helperText: error ? error : helperText ? helperText : null
      }));
    }
  });
}
